/***
 * Juliac
 * Copyright (C) 2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac.compile.janino;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.codehaus.janino.util.resource.Resource;

/**
 * A Janino resource stored in an array of chars.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.5
 */
public class CharArrayResource implements Resource {
	
	private String qname;
	private char[] content;
	
	public CharArrayResource( String qname, char[] content ) {
		this.qname = qname;
		this.content = content;
	}

    public InputStream open() throws IOException {
    	String str = new String(content);
    	byte[] buf = str.getBytes();
    	ByteArrayInputStream bais = new ByteArrayInputStream(buf);
    	return bais;
    }

    public String getFileName() {
    	return qname;
    }

    /**
     * Returns the time of the last modification, in milliseconds since
     * 1970, or <code>0L</code> if the time of the last modification cannot
     * be determined.
     */
    public long lastModified() { return 0L; }
}
